@@ -1,5 +1,5 @@
 """
-Copyright (c) 2008-2014, Jesus Cea Avion <jcea@jcea.es>
+Copyright (c) 2008-2018, Jesus Cea Avion <jcea@jcea.es>
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
@@ -356,6 +356,13 @@ if sys.version_info[0] >= 3 :
                 key = bytes(key, charset)
             return self._db.delete(key, txn=txn)
 
+        def compact(self, **kwargs) :
+            if isinstance(kwargs.get('start'), str) :
+                kwargs['start'] = bytes(kwargs['start'], charset)
+            if isinstance(kwargs.get('stop'), str) :
+                kwargs['stop'] = bytes(kwargs['stop'], charset)
+            return self._db.compact(**kwargs)
+
         def keys(self) :
             k = list(self._db.keys())
             if len(k) and isinstance(k[0], bytes) :
@@ -443,9 +450,6 @@ if sys.version_info[0] >= 3 :
         def get_dbp(self) :
             return self._db
 
-    import string
-    string.letters=[chr(i) for i in range(65,91)]
-
     bsddb._db.DBEnv_orig = bsddb._db.DBEnv
     bsddb._db.DB_orig = bsddb._db.DB
     bsddb._db.DBSequence_orig = bsddb._db.DBSequence
