@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 """
-Copyright (c) 2008-2014, Jesus Cea Avion <jcea@jcea.es>
+Copyright (c) 2008-2018, Jesus Cea Avion <jcea@jcea.es>
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
@@ -53,10 +53,7 @@ if (sys.version_info[0] < 3) and (sys.version_info >= (2, 6)) :
             category=DeprecationWarning)
 
     if sys.version_info[:2] == (2, 7) :
-        # We should use "with", but it is not available until Python 2.5.
-        context = warnings.catch_warnings()
-        context.__enter__()
-        try :
+        with warnings.catch_warnings() :
             # Python 2.7.0
             warnings.filterwarnings('ignore',
                 message='The CObject type is marked Pending Deprecation ' \
@@ -73,8 +70,6 @@ if (sys.version_info[0] < 3) and (sys.version_info >= (2, 6)) :
                 import bsddb  # Import the 2.7 version, that uses CObject
             except ImportError :
                 pass
-        finally :
-            context.__exit__()
 
     # setuptools warnings
     warnings.filterwarnings('ignore',
@@ -108,7 +103,7 @@ for line in _srcFile.readlines():
         VERSION = m.group(1)
         continue
 
-# We close first, to avoid a "ResourceWarning" under Python 3.2
+# We close first, to avoid a "ResourceWarning"
 _srcFile.close()
 del _srcFile
 del _ver_re
@@ -157,8 +152,8 @@ if os.name == 'posix':
         lflags_arg = LFLAGS + LIBS
 
     # Supported Berkeley DB versions, in order of preference.
-    db_ver_list = ((6, 1), (6, 0),
-            (5, 3), (5, 2), (5, 1), (5, 0),
+    db_ver_list = ((6, 2), (6, 1),
+            (5, 3), (5, 1),
             (4, 8), (4, 7))
     db_ver = None
 
@@ -173,7 +168,8 @@ if os.name == 'posix':
         bitness = ""
         import platform
         if (platform.architecture()[0] == "64bit") and \
-           (platform.platform(True, True).startswith("Solaris-")) :
+           (platform.platform(True, True).startswith("Solaris-")) and \
+           (not platform.uname()[3].startswith('joyent_')):
                bitness = "/64"
 
         for major, minor in db_ver_list :
@@ -182,8 +178,10 @@ if os.name == 'posix':
                 db_inc_paths.extend([
                     '/usr/include/db%d%s' %(major, bitness),
                     '/usr/local/include/db%d%s' %(major, bitness),
+                    '/opt/local/include/db%d%s' %(major, bitness),
                     '/opt/sfw/include/db%d%s' %(major, bitness),
                     '/sw/include/db%d%s' %(major, bitness),
+                    '/usr/local/opt/berkeley-db@%s/include' % (major),
                     ])
 
             db_inc_paths.append('/usr/include/db%d%d%s' % \
@@ -207,8 +205,11 @@ if os.name == 'posix':
             lib_dirs = compiler.library_dirs + [
                 '/lib64', '/usr/lib64',
                 '/lib', '/usr/lib',
+                '/usr/lib/x86_64-linux-gnu/',
+            ]
+            inc_dirs = compiler.include_dirs + [
+                '/usr/include', '/usr/local/opt/berkeley-db/include',
             ]
-            inc_dirs = compiler.include_dirs + ['/usr/include']
 
             # See whether there is a Oracle or Sleepycat header in the standard
             # search path.
@@ -216,10 +217,8 @@ if os.name == 'posix':
                 f = os.path.join(d, "db.h")
                 if debug: print "db: looking for db.h in", f
                 if os.path.exists(f):
-                    # This should move to "with" when we drop support for python 2.4 and 2.5
-                    fichero = open(f)
-                    f = fichero.read()
-                    fichero.close()
+                    with open(f) as fichero :
+                        f = fichero.read()
                     m = re.search(r"#define\WDB_VERSION_MAJOR\W(\d+)", f)
                     if m:
                         db_major = int(m.group(1))
@@ -260,7 +259,11 @@ if os.name == 'posix':
                 # XXX should we -ever- look for a dbX name?  Do any
                 # systems really not name their library by version and
                 # symlink to more general names?
-                for dblib in (('db-%d.%d' % db_ver), ('db%d' % db_ver[0])):
+                for dblib in (
+                        ('db%d-%d.%d' % (db_ver[0], db_ver[0], db_ver[1])),
+                        ('db-%d.%d' % db_ver),
+                        ('db%d' % db_ver[0])
+                        ):
                     dblib_file = compiler.find_library_file(
                                     db_dirs_to_check + lib_dirs, dblib )
                     if dblib_file:
@@ -335,10 +338,8 @@ if os.name == 'posix':
 
     # read db.h to figure out what version of Berkeley DB this is
     ver = None
-    # This should move to "with" when we drop support for Python 2.4 and 2.5
-    f = open(os.path.join(incdir, 'db.h'), 'r')
-    db_h_lines = f.readlines()
-    f.close()
+    with open(os.path.join(incdir, 'db.h'), 'r') as f :
+        db_h_lines = f.readlines()
     db_ver_re = re.compile(
         r'^#define\s+DB_VERSION_STRING\s.*Berkeley DB (\d+\.\d+).*')
     db_ver2 = db_ver
@@ -381,10 +382,8 @@ elif os.name == 'nt':
 
     # read db.h to figure out what version of Berkeley DB this is
     ver = None
-    # We should move this to "with" when we drop support for Python 2.4 and 2.5.
-    f = open(os.path.join(incdir, 'db.h'), 'r')
-    db_h_lines = f.readlines()
-    f.close()
+    with open(os.path.join(incdir, 'db.h'), 'r') as f :
+        db_h_lines = f.readlines()
     db_ver_re = re.compile(
         r'^#define\s+DB_VERSION_STRING\s.*Berkeley DB (\d+\.\d+).*')
     for line in db_h_lines:
@@ -419,7 +418,7 @@ elif os.name == 'nt':
              ("bsddb3/test", glob.glob("test/*.py"))
              ]
 
-if (db_ver in ((6, 0), (6, 1))) and \
+if (db_ver in ((6, 0), (6, 1), (6, 2))) and \
   ("YES_I_HAVE_THE_RIGHT_TO_USE_THIS_BERKELEY_DB_VERSION" not in os.environ) :
     print (
         "\n"
@@ -462,6 +461,26 @@ version_suffix = ""
 if sys.version_info[0] > 2 :
     version_suffix = "3"
 
+
+# #############################
+
+# Delete pkgsrc stale info
+# This is something that eventually should be not necesary.
+# XXX - jcea@jcea.es - 20170125
+from distutils import sysconfig
+
+# The same dictionary is always returned, so we abuse it
+# and modify it in place.
+config_vars = sysconfig.get_config_vars()
+for k, v in list(config_vars.items()):
+    if isinstance(v, str) and ('/db4' in v):
+        j = ' '.join([i for i in v.split() if not i.endswith('/db4')])
+        config_vars[k] = j
+del config_vars
+
+# #############################
+
+
 # do the actual build, install, whatever...
 setup(name = 'bsddb3',
       version = VERSION,
@@ -484,17 +503,17 @@ If you need to support ancient versiones of Python and/or Berkeley DB , you can
 use old releases of this bindings.
 
 
-`Homepage <http://www.jcea.es/programacion/
+`Homepage <https://www.jcea.es/programacion/
 pybsddb.htm>`__ --
-`Documentation <http://www.jcea.es/programacion/
+`Documentation <https://www.jcea.es/programacion/
 pybsddb_doc/>`__ --
 `Mailing List <https://mailman.jcea.es/listinfo/pybsddb>`__ --
-`Donation <http://www.jcea.es/programacion/pybsddb_doc/donate.html>`__
+`Donation <https://www.jcea.es/programacion/pybsddb_doc/donate.html>`__
 """,
 
       author = 'Jesus Cea, Robin Dunn, Gregory P. Smith, Andrew Kuchling, Barry Warsaw',
       author_email = 'pybsddb@jcea.es',
-      url = 'http://www.jcea.es/programacion/pybsddb.htm',
+      url = 'https://www.jcea.es/programacion/pybsddb.htm',
       license = "3-clause BSD License",
 
       packages = ['bsddb3', 'bsddb3/tests'],
@@ -527,9 +546,11 @@ pybsddb_doc/>`__ --
                     'Programming Language :: Python :: 2.6',
                     'Programming Language :: Python :: 2.7',
                     'Programming Language :: Python :: 3',
-                    'Programming Language :: Python :: 3.2',
                     'Programming Language :: Python :: 3.3',
                     'Programming Language :: Python :: 3.4',
+                    'Programming Language :: Python :: 3.5',
+                    'Programming Language :: Python :: 3.6',
+                    'Programming Language :: Python :: 3.7',
                     ],
       )
 
